@@ -31,6 +31,7 @@ class SWUGenerator:
         no_compress=False,
         no_encrypt=False,
         no_ivt=False,
+        no_hash=False
     ):
         self.swdescription = template
         self.artifacts = []
@@ -49,6 +50,7 @@ class SWUGenerator:
         self.nocompress = no_compress
         self.noencrypt = no_encrypt
         self.noivt = no_ivt
+        self.nohash = no_hash
 
     @staticmethod
     def generate_iv():
@@ -73,7 +75,7 @@ class SWUGenerator:
                 new = image
                 break
         if not new:
-            logging.debug("New artifact  %s", entry["filename"])
+            logging.debug("New artifact %s", entry["filename"])
             new = Artifact(entry["filename"])
             if not new.findfile(self.artifactory):
                 logging.critical("Artifact %s not found", entry["filename"])
@@ -107,6 +109,7 @@ class SWUGenerator:
                         "-z",
                         "-k",
                         "-T0",
+                        "-f",
                         "-c",
                         new.fullfilename,
                         ">",
@@ -181,6 +184,11 @@ class SWUGenerator:
                         entry["filename"],
                     )
                 if self.noivt:
+                    if not self.aesiv:
+                        logging.critical(
+                            "%s must be encrypted, but no initialization vector is given",
+                            entry["filename"],
+                        )
                     iv = self.aesiv
                 else:
                     iv = self.generate_iv()
@@ -195,10 +203,11 @@ class SWUGenerator:
 
             self.artifacts.append(new)
         else:
-            logging.debug("Artifact  %s already stored", entry["filename"])
+            logging.debug("Artifact %s already stored", entry["filename"])
 
         entry["filename"] = new.newfilename
-        entry["sha256"] = new.getsha256()
+        if not self.nohash:
+            entry["sha256"] = new.getsha256()
         if "encrypted" in entry:
             entry["ivt"] = new.ivt
 
@@ -264,6 +273,10 @@ class SWUGenerator:
                 logging.critical(
                     "sw-description must be encrypted, but no encryption key is given"
                 )
+            if not self.aesiv:
+                logging.critical(
+                    "sw-description must be encrypted, but no initialization vector is given"
+                )
 
             iv = self.aesiv
             sw.fullfilename = swdesc_filename
